pub struct ReplacerReplaceResponse {
pub response: String,
}Fields
response: StringTrait Implementations
Sourceimpl Clone for ReplacerReplaceResponse
impl Clone for ReplacerReplaceResponse
Sourcefn clone(&self) -> ReplacerReplaceResponse
fn clone(&self) -> ReplacerReplaceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplacerReplaceResponse
impl Debug for ReplacerReplaceResponse
Sourceimpl<D: ResourceDialect> Decode<ReplacerReplaceResponse, D> for ReplacerReplaceResponse
impl<D: ResourceDialect> Decode<ReplacerReplaceResponse, D> for ReplacerReplaceResponse
Sourceimpl<D: ResourceDialect> Encode<ReplacerReplaceResponse, D> for &ReplacerReplaceResponse
impl<D: ResourceDialect> Encode<ReplacerReplaceResponse, D> for &ReplacerReplaceResponse
Sourceimpl<D: ResourceDialect, T0: Encode<BoundedString<256>, D>> Encode<ReplacerReplaceResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<BoundedString<256>, D>> Encode<ReplacerReplaceResponse, D> for (T0,)
impl Eq for ReplacerReplaceResponse
Sourceimpl Hash for ReplacerReplaceResponse
impl Hash for ReplacerReplaceResponse
Sourceimpl Ord for ReplacerReplaceResponse
impl Ord for ReplacerReplaceResponse
Sourcefn cmp(&self, other: &ReplacerReplaceResponse) -> Ordering
fn cmp(&self, other: &ReplacerReplaceResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for ReplacerReplaceResponse
impl PartialEq for ReplacerReplaceResponse
Sourceimpl PartialOrd for ReplacerReplaceResponse
impl PartialOrd for ReplacerReplaceResponse
impl Persistable for ReplacerReplaceResponse
impl StructuralPartialEq for ReplacerReplaceResponse
Sourceimpl TypeMarker for ReplacerReplaceResponse
impl TypeMarker for ReplacerReplaceResponse
Sourcetype Owned = ReplacerReplaceResponse
type Owned = ReplacerReplaceResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ReplacerReplaceResponse
impl ValueTypeMarker for ReplacerReplaceResponse
Sourcetype Borrowed<'a> = &'a ReplacerReplaceResponse
type Borrowed<'a> = &'a ReplacerReplaceResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for ReplacerReplaceResponse
impl RefUnwindSafe for ReplacerReplaceResponse
impl Send for ReplacerReplaceResponse
impl Sync for ReplacerReplaceResponse
impl Unpin for ReplacerReplaceResponse
impl UnsafeUnpin for ReplacerReplaceResponse
impl UnwindSafe for ReplacerReplaceResponse